# This package contains uranie-launcher

- [This package contains uranie-launcher](#this-package-contains-uranie-launcher)
  - [Contact](#contact)
  - [Description](#description)
  - [Installation](#installation)
  - [Python style conventions](#python-style-conventions)

## Contact

 Clément STUTZ (<clement.stutz@cea.fr>)

## Description

The package **uranie_launcher** is a Python package for easily launch a study with URANIE.

## Installation

This package can be installed using pip.
For example the following line installs the package in developer mode (modifiable sources):

```sh
pip install --user -e .
```

## Python style conventions

This project use the code linter [Pylint](https://www.pylint.org/) for coding conventions
and [NumPy Style Python Docstrings](https://numpydoc.readthedocs.io/en/latest/format.html)
for docstrings formating.
